#[non_exhaustive]pub enum BuildError {
#[non_exhaustive] ResourceLimitReached {
resource: &'static str,
limit: usize,
},
#[non_exhaustive] CapacityTooLarge {
field: &'static str,
value: usize,
max: usize,
},
#[non_exhaustive] ThreadStartFailed {
component: &'static str,
worker: usize,
kind: ErrorKind,
raw_os_error: Option<i32>,
},
}Expand description
Failure to build a stopped Supervisor.
SupervisorBuilder::try_build returns this type while
validating capacities, reserving subscriber ownership, and starting required cleanup workers.
No Supervisor is returned on failure.
This enum and its data-carrying variants are non-exhaustive; keep a fallback arm and use .. when matching fields.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]ResourceLimitReached
The supervisor cannot reserve every required user-owned lifetime.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
#[non_exhaustive]CapacityTooLarge
A bounded async capacity exceeds Tokio’s structural limit.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
#[non_exhaustive]ThreadStartFailed
A required build-time cleanup worker could not start.
Subscriber metadata callbacks have not run when this error is returned.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
Implementations